.chip-container{column-gap:.625rem;display:flex;flex-wrap:wrap;list-style-type:none;padding-left:0;row-gap:.625rem}.chip{align-items:center;background-color:initial;border:.0625rem solid #31333f33;border-radius:.25rem;cursor:pointer;display:flex;height:28px;padding-left:.46875rem;padding-right:.46875rem}.chip.active{border-color:#000;color:#31333f}.chip-label-container#not-available{opacity:.6;pointer-events:none}.chip-status{margin-right:1.5px;width:.9rem}#status-icon{font-size:13px}.chip-label{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;font-size:.75rem;padding-right:10px;text-align:center;white-space:nowrap;width:100%}
/*# sourceMappingURL=main.fc2b76fd.css.map*/